"""
Common utils for inspur driver
"""

import base64
import rsa
from rsa import common
import sys
PYTHON_VERSION = int(sys.version_info.major)

class RsaUtil(object):
    """RSA Algorithm for password"""
    def __init__(self,pri_key_path):
        if pri_key_path:
            with open(pri_key_path) as pri_file:
                self.private_key = rsa.PrivateKey.load_pkcs1(pri_file.read())

    def get_max_length(self, rsa_key, encrypt=True):
        blocksize = common.byte_size(rsa_key.n)
        reserve_size = 11 
        if not encrypt: 
            reserve_size = 0
        maxlength = blocksize - reserve_size
        return maxlength

    def decrypt_by_private_key(self, message):
        """decrypt by private key."""
        decrypt_result = b""
        max_length = self.get_max_length(self.private_key, False)
        decrypt_message = base64.b64decode(message)
        while decrypt_message:
            input = decrypt_message[:max_length]
            decrypt_message = decrypt_message[max_length:]
            out = rsa.decrypt(input, self.private_key)
            decrypt_result += out
        if PYTHON_VERSION == 3:
            return str(decrypt_result,encoding='utf8')
        return decrypt_result


